# cashflows
Financial investment modeling and advanced engineering economics using Python.

The library can be installed as usual using `pip`:

    pip install cashflows


Click [here](http://cashflows.readthedocs.io/en/latest/) to access the
last documentation of the package.
